@@ -18,6 +18,9 @@
 
 from dingos.importer import DingoImportCommand
 from mantis_stix_importer.importer import STIX_Import
+from optparse import make_option
+
+
 
 class Command(DingoImportCommand):
     """
@@ -25,6 +28,15 @@ class Command(DingoImportCommand):
     files into DINGO.
     """
 
+    option_list = DingoImportCommand.option_list + (
+        make_option('-t', '--default-timestamp',
+                    action='store',
+                    dest='default_timestamp',
+                    default=None,
+                    help="""Set default timestamp."""),
+    )
+
+
     Importer = STIX_Import()
 
     help = 'Imports STIX XML files of specified paths into DINGO'
